==> libreoffice-bootstrap-3.3.2.2.tar.bz2: libreoffice-bootstrap-3.3.2.2/solenv/bin/modules/installer/remover.pm <==
#*************************************************************************
#
# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
# 
# Copyright 2000, 2010 Oracle and/or its affiliates.
#
# OpenOffice.org - a multi-platform office productivity suite
#
# This file is part of OpenOffice.org.
#
# OpenOffice.org is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# only, as published by the Free Software Foundation.
#
# OpenOffice.org is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License version 3 for more details
# (a copy is included in the LICENSE file that accompanied this code).
#
# You should have received a copy of the GNU Lesser General Public License
# version 3 along with OpenOffice.org.  If not, see
# <http://www.openoffice.org/license.html>
# for a copy of the LGPLv3 License.
#
#*************************************************************************

package installer::remover;

use installer::globals;

############################################
# Remover
############################################

sub remove_leading_and_ending_whitespaces
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*//;
    $$stringref =~ s/\s*$//;	
}

sub remove_leading_and_ending_quotationmarks
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\"//;
    $$stringref =~ s/\"\s*$//;	
}

sub remove_leading_and_ending_slashes
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\///g;
    $$stringref =~ s/\/\s*$//g;	
}

sub remove_ending_slashes
{
    my ( $stringref ) = @_;

    $$stringref =~ s/\/\s*$//g;	
}

sub remove_leading_and_ending_pathseparators
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\Q$installer::globals::separator\E//;
    $$stringref =~ s/\Q$installer::globals::separator\E\s*$//;	
}

sub remove_ending_pathseparator
{
    my ( $stringref ) = @_;

    $$stringref =~ s/\Q$installer::globals::separator\E\s*$//;	
}

1;

==> libreoffice-bootstrap-3.4.3.2.tar.bz2: libreoffice-bootstrap-3.4.3.2/solenv/bin/modules/installer/remover.pm <==
#*************************************************************************
#
# DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
# 
# Copyright 2000, 2010 Oracle and/or its affiliates.
#
# OpenOffice.org - a multi-platform office productivity suite
#
# This file is part of OpenOffice.org.
#
# OpenOffice.org is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# only, as published by the Free Software Foundation.
#
# OpenOffice.org is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License version 3 for more details
# (a copy is included in the LICENSE file that accompanied this code).
#
# You should have received a copy of the GNU Lesser General Public License
# version 3 along with OpenOffice.org.  If not, see
# <http://www.openoffice.org/license.html>
# for a copy of the LGPLv3 License.
#
#*************************************************************************

package installer::remover;

use installer::globals;

############################################
# Remover
############################################

sub remove_leading_and_ending_whitespaces
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s+//;
    $$stringref =~ s/\s+$//;
}

sub remove_leading_and_ending_quotationmarks
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\"//;
    $$stringref =~ s/\"\s*$//;	
}

sub remove_leading_and_ending_slashes
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\///g;
    $$stringref =~ s/\/\s*$//g;	
}

sub remove_ending_slashes
{
    my ( $stringref ) = @_;

    $$stringref =~ s/\/\s*$//g;	
}

sub remove_leading_and_ending_pathseparators
{
    my ( $stringref ) = @_;

    $$stringref =~ s/^\s*\Q$installer::globals::separator\E//;
    $$stringref =~ s/\Q$installer::globals::separator\E\s*$//;	
}

sub remove_ending_pathseparator
{
    my ( $stringref ) = @_;

    $$stringref =~ s/\Q$installer::globals::separator\E\s*$//;	
}

1;
